{% set fullname = fullname | replace(module ~ ".", "") %}
{{ fullname | escape | underline }}

.. currentmodule:: {{ module }}

.. autoclass:: {{ objname }}

{% block methods %}
{% if methods %}
   .. rubric:: Methods

   .. autosummary::
      :toctree: .
   {% for item in methods %}
      {{ name }}.{{ item }}
   {% endfor %}
{% endif %}
{% endblock %}


{% block attributes %}
{% if attributes %}
   .. rubric:: Attributes

   .. autosummary::
      :toctree: .
   {% for item in attributes %}
      {{ name }}.{{ item }}
   {% endfor %}
{% endif %}
{% endblock %}